==> kpimtextedit-16.08.3.tar.xz: kpimtextedit-16.08.3/src/texttospeech/abstracttexttospeechconfiginterface.h <==
/*
   Copyright (C) 2014-2016 Laurent Montel <montel@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef ABSTRACTTEXTTOSPEECHCONFIGINTERFACE_H
#define ABSTRACTTEXTTOSPEECHCONFIGINTERFACE_H

#include <QLocale>
#include <QVector>
#include <QObject>
#include "kpimtextedit_export.h"
namespace KPIMTextEdit
{
class KPIMTEXTEDIT_EXPORT AbstractTextToSpeechConfigInterface : public QObject
{
    Q_OBJECT
public:
    explicit AbstractTextToSpeechConfigInterface(QObject *parent = Q_NULLPTR);
    ~AbstractTextToSpeechConfigInterface();
    virtual QVector<QLocale> availableLocales() const;
    virtual QLocale locale() const;
    virtual void setLocale(const QLocale &locale);

    virtual QStringList availableEngines() const;
    virtual QStringList availableVoices() const;
    virtual void setEngine(const QString &engineName);
};
}

#endif // ABSTRACTTEXTTOSPEECHCONFIGINTERFACE_H

==> kpimtextedit-17.04.3.tar.xz: kpimtextedit-17.04.3/src/texttospeech/abstracttexttospeechconfiginterface.h <==
/*
   Copyright (C) 2014-2016 Laurent Montel <montel@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef ABSTRACTTEXTTOSPEECHCONFIGINTERFACE_H
#define ABSTRACTTEXTTOSPEECHCONFIGINTERFACE_H

#include <QLocale>
#include <QVector>
#include <QObject>
#include "kpimtextedit_export.h"
namespace KPIMTextEdit
{
class KPIMTEXTEDIT_EXPORT AbstractTextToSpeechConfigInterface : public QObject
{
    Q_OBJECT
public:
    explicit AbstractTextToSpeechConfigInterface(QObject *parent = nullptr);
    ~AbstractTextToSpeechConfigInterface();
    virtual QVector<QLocale> availableLocales() const;
    virtual QLocale locale() const;
    virtual void setLocale(const QLocale &locale);

    virtual QStringList availableEngines() const;
    virtual QStringList availableVoices() const;
    virtual void setEngine(const QString &engineName);
};
}

#endif // ABSTRACTTEXTTOSPEECHCONFIGINTERFACE_H
